@@ -1,7 +1,7 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 1.48 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: autogen.c,v 1.51 2004/10/07 16:03:58 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -45,7 +45,7 @@ STATIC void signalExit( int sig );
 STATIC void
 inner_main( int argc, char** argv )
 {
-    doOptions( argc, argv );
+    initialize( argc, argv );
 
     procState = PROC_STATE_LOAD_DEFS;
     readDefines();
@@ -387,6 +387,16 @@ signalSetup( void )
             sa.sa_handler = SIG_IGN;
             break;
 
+#ifdef DAEMON_ENABLED
+# error DAEMON-ization of AutoGen is not ready for prime time
+        case SIGHUP:
+            if (HAVE_OPT( DAEMON )) {
+                sa.sa_handler = handleSighup;
+                break;
+            }
+            /* FALLTHROUGH */
+#endif
+
         default:
             sa.sa_handler = abendSignal;
         }
